// Electrokinetic problem: Plate with 3 holes

// Geometrical parameters

xPl = 0.18 ;
yPl = 0.09 ;

rC = 0.012 ;

x1 = 0.06 ;  y1 = 0.045 ;
x2 = 0.10 ;  y2 = 0.065 ;
x3 = 0.12 ;  y3 = 0.025 ;

// Mesh size

p0 = yPl / 15 ;
p1 = 2.*3.1415926535897 * rC / 20. ;

// Points

Point(1) = { 0. , 0. , 0., p0} ;
Point(2) = { xPl, 0. , 0., p0} ;
Point(3) = { xPl, yPl, 0., p0} ;
Point(4) = { 0. , yPl, 0., p0} ;


Point(11) = { x1 , y1 , 0., p1} ;
Point(12) = { x1+rC , y1 , 0., p1} ;
Point(13) = { x1-rC , y1 , 0., p1} ;

Point(21) = { x2 , y2 , 0., p1} ;
Point(22) = { x2+rC , y2 , 0., p1} ;
Point(23) = { x2-rC , y2 , 0., p1} ;

Point(31) = { x3 , y3 , 0., p1} ;
Point(32) = { x3+rC , y3 , 0., p1} ;
Point(33) = { x3-rC , y3 , 0., p1} ;

// Lines

Circle(1) = {12,11,13} Plane {0,0,1};
Circle(2) = {13,11,12} Plane {0,0,1};
Circle(3) = {22,21,23} Plane {0,0,1};
Circle(4) = {23,21,22} Plane {0,0,1};
Circle(5) = {32,31,33} Plane {0,0,1};
Circle(6) = {33,31,32} Plane {0,0,1};

Line(7) = {1,2};
Line(8) = {2,3};
Line(9) = {3,4};
Line(10) = {4,1};

// Surfaces

Line Loop(11) = {8,9,10,7};
Line Loop(12) = {5,6};
Line Loop(13) = {3,4};
Line Loop(14) = {1,2};
Plane Surface(15) = {11,12,13,14};

Plane Surface(21) = {14};
Plane Surface(22) = {13};
Plane Surface(23) = {12};


// Physical Regions

Physical Surface (101) = {15} ; // Plate

Physical Line (300) = { 8} ; // Elec0
Physical Line (301) = {10} ; // Elec1

Physical Surface (111) = {21} ; // Disk1
Physical Surface (112) = {22} ; // Disk2
Physical Surface (113) = {23} ; // Disk3

Physical Line (401) = {7} ; // SurConv1
Physical Line (402) = {9} ; // SurConv2
