/* Electrokinetic problem: Plate with 3 disks */
// Patrick Dular

/* Geometry (2D)

        +------------------------------------------------------+
        |                              ___                     |
 Elec1  |       Plate                 /   \                    |
      \ |                            |Disk2|                   |
        |               ___           \___/                    |
        |              /   \                                   |
        |             |Disk1|                                  |
        |              \___/                ___                |
        |                                  /   \               |
        |                                 |Disk3|              | \
        |                                  \___/               |  Elec0
        |                                                      |
        +------------------------------------------------------+

  2D elements in: Plate, Disk1, Disk2, Disk3
  1D elements in: Elec0, Elec1
*/

Group {
  Plate = # 101 ;

  Disk1 = # 111 ;  Disk2 = # 112 ;  Disk3 = # 113 ;

  Elec0 = # 300 ;  Elec1 = # 301 ;

  DomainC_Ele = Region[ {Plate, Disk1, Disk2, Disk3} ] ;

  Electrode_Ele = Region[{Elec1}] ;
}


/* --------------------------------------------------------------------------*/

Function {

  sigma0 = 5.9e7 ;

  sigma [ Plate ] = sigma0/10. ;

  sigma [ Disk1 ] = sigma0 ;
  sigma [ Disk2 ] = sigma0 ;
  sigma [ Disk3 ] = sigma0 ;

  Thickness = 0.001 ;

}


/* --------------------------------------------------------------------------*/

Constraint {

  { Name ElectricScalarPotential ;
    Case { /* A reference must be given for the scalar potential */
      { Region Elec0 ; Value 0. ; }
    }
  }

  /* Either the potential is fixed... */

  { Name GlobalElectricPotential ;
    Case {
      { Region Elec1 ; Value 1.e-3 ; }
    }
  }

  /* ... or the current is fixed */


  { Name GlobalElectricCurrent ;
    Case {
      //      { Region Elec1 ; Value 1. ; }
    }
  }


}


Include "../Jacobian_Lib.pro"
Include "../Integration_Lib.pro"

Include "../EleKin_v.pro"
Include "../EleKin_vf.pro"


PostOperation Map_v UsingPost EleKin_v {
  Print[ v, OnElementsOf DomainC_Ele, File "PlateWithDisks_v.pos" ] ;
}

PostOperation Map_j UsingPost EleKin_v {
  Print[ j, OnElementsOf DomainC_Ele, File "PlateWithDisks_j.pos" ] ;
}

PostOperation Map_jg UsingPost EleKin_v {
  Print[ j, OnPlane { {0.001,0.001,0} {0.179,0.001,0} {0.001,0.089,0} } {36,18}, 
         File "PlateWithDisks_jg.pos" ] ;
}


PostOperation Val_V UsingPost EleKin_vf {
  Print[ V, OnRegion Electrode_Ele ] ;
  Print[ I, OnRegion Electrode_Ele ] ;
  Print[ R, OnRegion Electrode_Ele ] ;
}
